utils

package
v0.10.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 10, 2022 License: MIT Imports: 1 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var IsRepl = false

IsRepl is used by the repl and environment to determine whether to exit and whether mutable variables are allowed at the top level

Functions

func ExitConditionally

func ExitConditionally(code int)

ExitConditionally exits only if we're not currently in a REPL

func SetReplOrRun

func SetReplOrRun(rep bool)

SetReplOrRun sets if the program is running in a repl or running code (either in a file or evaling a string); used below in ExitConditionally

Types

This section is empty.

Jump to