Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var IsRepl = false
IsRepl is used by the repl and environment to determine whether to exit and whether mutable variables are allowed at the top level
Functions ¶
func ExitConditionally ¶
func ExitConditionally(code int)
ExitConditionally exits only if we're not currently in a REPL
func SetReplOrRun ¶
func SetReplOrRun(rep bool)
SetReplOrRun sets if the program is running in a repl or running code (either in a file or evaling a string); used below in ExitConditionally
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.